Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1156)

Unified Diff: media/blink/websourcebuffer_impl.cc

Issue 1312763014: Rename WebSourceBuffer::abort -> resetParserState (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/blink/websourcebuffer_impl.h ('k') | media/filters/chunk_demuxer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/blink/websourcebuffer_impl.cc
diff --git a/media/blink/websourcebuffer_impl.cc b/media/blink/websourcebuffer_impl.cc
index 03a824b8680b2043b4157fb84f00bc4abdad1e46..35ba8c04eeba17eb7904833176d756291342362b 100644
--- a/media/blink/websourcebuffer_impl.cc
+++ b/media/blink/websourcebuffer_impl.cc
@@ -110,13 +110,19 @@ void WebSourceBufferImpl::append(
*timestamp_offset = timestamp_offset_.InSecondsF();
}
+// TODO(servolk): WebSourceBuffer::abort is being renamed into
+// resetParserState and will be removed soon
void WebSourceBufferImpl::abort() {
- demuxer_->Abort(id_,
- append_window_start_, append_window_end_,
- &timestamp_offset_);
+ resetParserState();
+}
+
+void WebSourceBufferImpl::resetParserState() {
+ demuxer_->ResetParserState(id_,
+ append_window_start_, append_window_end_,
+ &timestamp_offset_);
- // TODO(wolenetz): abort should be able to modify the caller timestamp offset
- // (just like WebSourceBufferImpl::append).
+ // TODO(wolenetz): resetParserState should be able to modify the caller
+ // timestamp offset (just like WebSourceBufferImpl::append).
// See http://crbug.com/370229 for further details.
}
« no previous file with comments | « media/blink/websourcebuffer_impl.h ('k') | media/filters/chunk_demuxer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698